cli

package
v0.0.0-alpha.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2026 License: MIT Imports: 17 Imported by: 0

Documentation

Overview

Package cli wires together all buildgraph subcommands and viper config initialisation. The binary entry point in cmd/main.go calls Execute().

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute is the single entry point called by cmd/main.go.

Types

This section is empty.

Jump to