diff

package
v0.0.0-alpha.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Detector

type Detector struct {
	// contains filtered or unexported fields
}

Detector compares the current state of the codebase against a previous baseline and produces a list of semantic Changes.

func NewDetector

func NewDetector(
	current map[string]*types.Function,
	extDeps map[string]string,
	extHash string,
	previous *types.Baseline,
) *Detector

func (*Detector) DetectChanges

func (d *Detector) DetectChanges() []types.Change

DetectChanges returns all semantic changes since the previous baseline.

Jump to