Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Detector ¶
type Detector struct {
// contains filtered or unexported fields
}
Detector compares the current state of the codebase against a previous baseline and produces a list of semantic Changes.
func NewDetector ¶
func (*Detector) DetectChanges ¶
DetectChanges returns all semantic changes since the previous baseline.
Click to show internal directories.
Click to hide internal directories.